.. _psn_with_pharmpy:

================
PsN with Pharmpy
================

Pharmpy has support to read and postprocess results in PsN.

~~~~~~~~~~~~~~~~~~~~~~
Tools connected to PsN
~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   bootstrap
   cdd
   crossval
   frem
   linearize
   qa
   resmod <psn_resmod>
   scm
   simeval
